Ext.data.JsonP.dataview({"guide":"<h1 id='dataview-section-using-dataviews-in-sencha-touch'>Using DataViews in Sencha Touch</h1>\n<div class='toc'>\n<p><strong>Contents</strong></p>\n<ol>\n<li><a href='#!/guide/dataview-section-creating-a-simple-dataview'>Creating a Simple DataView</a></li>\n<li><a href='#!/guide/dataview-section-loading-data-from-a-server'>Loading Data from a Server</a></li>\n<li><a href='#!/guide/dataview-section-styling-a-dataview'>Styling a DataView</a></li>\n<li><a href='#!/guide/dataview-section-component-dataview'>Component DataView</a></li>\n</ol>\n</div>\n\n<p><a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> makes it easy to create dynamically a number of components, usually based off a <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a>. It is used for rendering data from your server backend or any other data source, and it powers components such as <a href=\"#!/api/Ext.dataview.List\" rel=\"Ext.dataview.List\" class=\"docClass\">Ext.List</a>.</p>\n\n<p>You can use <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> whenever you want to show repeatedly sets of the same component, for example in cases such as the following:</p>\n\n<ul>\n<li>A list of messages in an email app</li>\n<li>A list of the latest news or tweets</li>\n<li>A tiled set of albums in an HTML5 music player</li>\n</ul>\n\n\n<h2 id='dataview-section-creating-a-simple-dataview'>Creating a Simple DataView</h2>\n\n<p>At its simplest, a <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> is a <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a> full of data and a template that is used to render each store item, as illustrated by the following example:</p>\n\n<pre class='inline-example '><code>var touchTeam = <a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">Ext.DataView</a>', {\n    fullscreen: true,\n\n    store: {\n        fields: ['name', 'age'],\n        data: [\n            {name: 'Jamie Avins',  age: 100},\n            {name: 'Rob Dougan',   age: 21},\n            {name: 'Tommy Maintz', age: 24},\n            {name: 'Jacky Nguyen', age: 24},\n            {name: 'Ed Spencer',   age: 26}\n        ]\n    },\n\n    itemTpl: '{name} is {age} years old'\n});\n</code></pre>\n\n<p>In this example we defined the store inline, so all data is local and therefore does not have to be loaded from a server. For each of the five data items defined in the <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a>, <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> renders a <a href=\"#!/api/Ext.Component\" rel=\"Ext.Component\" class=\"docClass\">Component</a> and passes in the name and age data. The component uses the specified <a href=\"#!/api/Ext.dataview.DataView-cfg-itemTpl\" rel=\"Ext.dataview.DataView-cfg-itemTpl\" class=\"docClass\">tpl</a> and renders the data inside the curly bracket placeholders.</p>\n\n<p>Because <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> is integrated with <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a>, any changes to the <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a> are immediately reflected on the screen. For example, if we added a new record to the <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a>, it would be rendered into our <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a>:</p>\n\n<pre><code>touchTeam.getStore().add({\n    name: 'Abe Elias',\n    age: 33\n});\n</code></pre>\n\n<p>After adding the new record as shown in the previous code sample, we do not have to manually update the <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a>, since it is automatically updated. The same would happen if we modified one of the existing records in the <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a>:</p>\n\n<pre><code>touchTeam.getStore().getAt(0).set('age', 42);\n</code></pre>\n\n<p>This will get the first record in the <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a> (Jamie), change his age to 42 and automatically update the screen content.</p>\n\n<h2 id='dataview-section-loading-data-from-a-server'>Loading Data from a Server</h2>\n\n<p>We often want to load data from our server or some other web service, so that we do not have to hard-code the data content locally. Let us say we wanted to load the latest tweets about Sencha Touch into a <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a>, and for each tweet render the user's profile picture, the user name and the tweet message. To do this we need to modify the <a href=\"#!/api/Ext.dataview.DataView-cfg-store\" rel=\"Ext.dataview.DataView-cfg-store\" class=\"docClass\">store</a> and <a href=\"#!/api/Ext.dataview.DataView-cfg-itemTpl\" rel=\"Ext.dataview.DataView-cfg-itemTpl\" class=\"docClass\">itemTpl</a> as follows:</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">Ext.DataView</a>', {\n    fullscreen: true,\n\n    store: {\n        autoLoad: true,\n        fields: ['from_user', 'text', 'profile_image_url'],\n\n        proxy: {\n            type: 'jsonp',\n            url: 'http://search.twitter.com/search.json?q=Sencha Touch',\n\n            reader: {\n                type: 'json',\n                rootProperty: 'results'\n            }\n        }\n    },\n\n    itemTpl: '&lt;img src=\"{profile_image_url}\" /&gt;&lt;h2&gt;{from_user}&lt;/h2&gt;&lt;p&gt;{text}&lt;/p&gt;'\n});\n</code></pre>\n\n<p>In this example, the <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> no longer contains data items, instead we have provided a <a href=\"#!/api/Ext.data.proxy.Proxy\" rel=\"Ext.data.proxy.Proxy\" class=\"docClass\">Proxy</a>, which fetches the data. In this case we used a JSON-P proxy that loads data using Twitter's JSON-P search API. We also specified the fields present for each tweet, and used Store's <a href=\"#!/api/Ext.data.Store-cfg-autoLoad\" rel=\"Ext.data.Store-cfg-autoLoad\" class=\"docClass\">autoLoad</a> configuration to load the data automatically. Finally, we configured a Reader to decode the response from Twitter, indicating it to expect JSON and that the tweets are found in the 'results' part of the JSON response.</p>\n\n<p>As the last operation we updated the template to render the image, the twitter username and the message. Finally, all that is still required is adding some CSS to style the list as desired.</p>\n\n<h2 id='dataview-section-styling-a-dataview'>Styling a DataView</h2>\n\n<p>You may have realized by now that although our <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> is displaying data from our <a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Store</a>, it does not have any default styling. The lack of default styling is by design, but adding custom CSS is very simple. <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> has two configurations that support targeting your custom CSS to the view: <a href=\"#!/api/Ext.dataview.DataView-cfg-baseCls\" rel=\"Ext.dataview.DataView-cfg-baseCls\" class=\"docClass\">baseCls</a> and <a href=\"#!/api/Ext.dataview.DataView-cfg-itemCls\" rel=\"Ext.dataview.DataView-cfg-itemCls\" class=\"docClass\">itemCls</a>. <a href=\"#!/api/Ext.dataview.DataView-cfg-baseCls\" rel=\"Ext.dataview.DataView-cfg-baseCls\" class=\"docClass\">baseCls</a> is used to add a <code>className</code> around the outer element of the <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a>. The <a href=\"#!/api/Ext.dataview.DataView-cfg-itemCls\" rel=\"Ext.dataview.DataView-cfg-itemCls\" class=\"docClass\">itemCls</a> you provide is added onto each item that is rendered into our <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a>.</p>\n\n<p>If you do <em>not</em> specify an <a href=\"#!/api/Ext.dataview.DataView-cfg-itemCls\" rel=\"Ext.dataview.DataView-cfg-itemCls\" class=\"docClass\">itemCls</a>, it automatically takes the <a href=\"#!/api/Ext.dataview.DataView-cfg-baseCls\" rel=\"Ext.dataview.DataView-cfg-baseCls\" class=\"docClass\">baseCls</a> configuration (which defaults to <code>x-dataview</code>) and prepends <code>-item</code> to it. As a result, each item will have a className of <code>x-dataview-item</code>.</p>\n\n<p>Before adding the configuration, we need to create the custom CSS shown in the following example:</p>\n\n<pre><code>.my-dataview-item {\n    background: #ddd;\n    padding: 1em;\n    border-bottom: 1px solid #ccc;\n}\n.my-dataview-item img {\n    float: left;\n    margin-right: 1em;\n}\n.my-dataview-item h2 {\n    font-weight: bold;\n}\n</code></pre>\n\n<p>Once the CSS is complete, we can go back to our previous Twitter example and add the <a href=\"#!/api/Ext.dataview.DataView-cfg-baseCls\" rel=\"Ext.dataview.DataView-cfg-baseCls\" class=\"docClass\">baseCls</a> configuration:</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">Ext.DataView</a>', {\n    fullscreen: true,\n\n    store: {\n        autoLoad: true,\n        fields: ['from_user', 'text', 'profile_image_url'],\n\n        proxy: {\n            type: 'jsonp',\n            url: 'http://search.twitter.com/search.json?q=Sencha Touch',\n\n            reader: {\n                type: 'json',\n                root: 'results'\n            }\n        }\n    },\n\n    itemTpl: '&lt;img src=\"{profile_image_url}\" /&gt;&lt;h2&gt;{from_user}&lt;/h2&gt;&lt;p&gt;{text}&lt;/p&gt;',\n\n    baseCls: 'my-dataview'\n\n    //As described above, we don't need to set itemCls in most cases as it will already add a className\n    //generated from the baseCls to each item.\n    //itemCls: 'my-dataview-item'\n});\n</code></pre>\n\n<h2 id='dataview-section-component-dataview'>Component DataView</h2>\n\n<p>In the previous example we created a <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> with an <a href=\"#!/api/Ext.dataview.DataView-cfg-itemTpl\" rel=\"Ext.dataview.DataView-cfg-itemTpl\" class=\"docClass\">itemTpl</a>, which means each item is rendered from a <a href=\"#!/api/Ext.XTemplate\" rel=\"Ext.XTemplate\" class=\"docClass\">template</a>. However, sometimes you need each item to be a component, so you can provide a rich UI for users. In Sencha Touch, we introduced the <a href=\"#!/api/Ext.dataview.DataView-cfg-useComponents\" rel=\"Ext.dataview.DataView-cfg-useComponents\" class=\"docClass\">useComponents</a> configuration which allows you to address this scenario.</p>\n\n<p>Creating a component <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> is very similar to creating a normal template-based <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> as previously shown, however you must define the item view used when rendering each item in your list.</p>\n\n<pre><code><a href=\"#!/api/Ext-method-define\" rel=\"Ext-method-define\" class=\"docClass\">Ext.define</a>('MyListItem', {\n    extend: '<a href=\"#!/api/Ext.dataview.component.DataItem\" rel=\"Ext.dataview.component.DataItem\" class=\"docClass\">Ext.dataview.component.DataItem</a>',\n    requires: ['<a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>'],\n    xtype: 'mylistitem',\n\n    config: {\n        nameButton: true,\n\n        dataMap: {\n            getNameButton: {\n                setText: 'name'\n            }\n        }\n    },\n\n    applyNameButton: function(config) {\n        return <a href=\"#!/api/Ext-method-factory\" rel=\"Ext-method-factory\" class=\"docClass\">Ext.factory</a>(config, <a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>, this.getNameButton());\n    },\n\n    updateNameButton: function(newNameButton, oldNameButton) {\n        if (oldNameButton) {\n            this.remove(oldNameButton);\n        }\n\n        if (newNameButton) {\n            this.add(newNameButton);\n        }\n    }\n});\n</code></pre>\n\n<p>This example shows how to define a component-based <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> item component. There are a few important notes about this example:</p>\n\n<ul>\n<li>We must extend <a href=\"#!/api/Ext.dataview.component.DataItem\" rel=\"Ext.dataview.component.DataItem\" class=\"docClass\">Ext.dataview.component.DataItem</a> for each item. This is an abstract class which handles the record handling for each item.</li>\n<li>Following the extend code we require <a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>, because we intend to insert a <a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">button</a> inside the item component.</li>\n<li>We specify the <code>xtype</code> for this item component.</li>\n<li>Inside the config block we define the <code>nameButton</code> item. This custom configuration added to the component will be transformed into a <a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">button</a> by the <a href=\"#!/guide/class_system\">class system</a>. By default we set it to <code>true</code> , but this could also be a configuration block. This configuration automatically generates getters and setters for the <code>nameButton</code> item.</li>\n<li>We define the <a href=\"#!/api/Ext.dataview.component.DataItem-cfg-dataMap\" rel=\"Ext.dataview.component.DataItem-cfg-dataMap\" class=\"docClass\">dataMap</a>. The dataMap is a map between the data of a <a href=\"#!/api/Ext.data.Model\" rel=\"Ext.data.Model\" class=\"docClass\">record</a> and this view. The <code>getNameButton</code> is the getter for the instance you want to update; so in this case we want to get the <code>nameButton</code> configuration of this component. Inside that block we then give it the setter for that instance, <code>setText</code> in this case and give it the field of the record we are passing. As a result, once this item component gets a record, it gets the <code>nameButton</code> and then calls <code>setText</code> with the <code>name</code> value of the record.</li>\n<li>Finally we define the apply method for the <code>nameButton</code> item. The apply method uses <a href=\"#!/api/Ext-method-factory\" rel=\"Ext-method-factory\" class=\"docClass\">Ext.factory</a> to transform the configuration passed into an instance of <a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>. That instance is then returned, which  then causes <code>updateNameButton</code> to be called. The <code>updateNameButton</code> method removes the old nameButton instance if it exists, and adds the new nameButton instance if it exists.</li>\n</ul>\n\n\n<p>After having created the item component, we can create the component <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a>, similar to previous examples.</p>\n\n<pre><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">Ext.DataView</a>', {\n    fullscreen: true,\n\n    store: {\n        fields: ['name', 'age'],\n        data: [\n            {name: 'Jamie Avins',  age: 100},\n            {name: 'Rob Dougan',   age: 21},\n            {name: 'Tommy Maintz', age: 24},\n            {name: 'Jacky Nguyen', age: 24},\n            {name: 'Ed Spencer',   age: 26}\n        ]\n    },\n\n    useComponents: true,\n    defaultType: 'mylistitem'\n});\n</code></pre>\n\n<p>This code has two key additions. First, we added the <a href=\"#!/api/Ext.dataview.DataView-cfg-useComponents\" rel=\"Ext.dataview.DataView-cfg-useComponents\" class=\"docClass\">useComponents</a> configuration and set it to <code>true</code>. Second, we set the <a href=\"#!/api/Ext.dataview.DataView-cfg-defaultType\" rel=\"Ext.dataview.DataView-cfg-defaultType\" class=\"docClass\">defaultType</a> configuration to the previously created <code>mylistitem</code> item component. This tells the <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> to use the defined item component as the view for each item.</p>\n\n<p>If we run this code together, we can see the component <a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">DataView</a> in action.</p>\n\n<pre class='inline-example preview'><code><a href=\"#!/api/Ext-method-define\" rel=\"Ext-method-define\" class=\"docClass\">Ext.define</a>('MyListItem', {\n    extend: '<a href=\"#!/api/Ext.dataview.component.DataItem\" rel=\"Ext.dataview.component.DataItem\" class=\"docClass\">Ext.dataview.component.DataItem</a>',\n    requires: ['<a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>'],\n    xtype: 'mylistitem',\n\n    config: {\n        nameButton: true,\n\n        dataMap: {\n            getNameButton: {\n                setText: 'name'\n            }\n        }\n    },\n\n    applyNameButton: function(config) {\n        return <a href=\"#!/api/Ext-method-factory\" rel=\"Ext-method-factory\" class=\"docClass\">Ext.factory</a>(config, <a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>, this.getNameButton());\n    },\n\n    updateNameButton: function(newNameButton, oldNameButton) {\n        if (oldNameButton) {\n            this.remove(oldNameButton);\n        }\n\n        if (newNameButton) {\n            this.add(newNameButton);\n        }\n    }\n});\n\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">Ext.DataView</a>', {\n    fullscreen: true,\n\n    store: {\n        fields: ['name', 'age'],\n        data: [\n            {name: 'Jamie Avins',  age: 100},\n            {name: 'Rob Dougan',   age: 21},\n            {name: 'Tommy Maintz', age: 24},\n            {name: 'Jacky Nguyen', age: 24},\n            {name: 'Ed Spencer',   age: 26}\n        ]\n    },\n\n    useComponents: true,\n    defaultType: 'mylistitem'\n});\n</code></pre>\n\n<p>The great benefit of this approach is the flexibility it adds to your dataviews. Since each item component has access to its own <a href=\"#!/api/Ext.dataview.component.DataItem-cfg-record\" rel=\"Ext.dataview.component.DataItem-cfg-record\" class=\"docClass\">record</a>, you can do just about anything with it.</p>\n\n<p>In the following example we add to the <code>nameButton</code> an event listener to the tap event, which alerts the user with the age of the selected person.</p>\n\n<pre><code><a href=\"#!/api/Ext-method-define\" rel=\"Ext-method-define\" class=\"docClass\">Ext.define</a>('MyListItem', {\n    //...\n\n    updateNameButton: function(newNameButton, oldNameButton) {\n        if (oldNameButton) {\n            this.remove(oldNameButton);\n        }\n\n        if (newNameButton) {\n            // add an event listeners for the `tap` event onto the new button, and tell it to call the onNameButtonTap method\n            // when it happens\n            newNameButton.on('tap', this.onNameButtonTap, this);\n\n            this.add(newNameButton);\n        }\n    },\n\n    onNameButtonTap: function(button, e) {\n        var record = this.getRecord();\n\n        <a href=\"#!/api/Ext.Msg-method-alert\" rel=\"Ext.Msg-method-alert\" class=\"docClass\">Ext.Msg.alert</a>(\n            record.get('name'), // the title of the alert\n            \"The age of this person is: \" + record.get('age') // the message of the alert\n        );\n    }\n});\n</code></pre>\n\n<p>Finally, after adding this code to our previous example, we get the following finished result:</p>\n\n<pre class='inline-example preview'><code><a href=\"#!/api/Ext-method-define\" rel=\"Ext-method-define\" class=\"docClass\">Ext.define</a>('MyListItem', {\n    extend: '<a href=\"#!/api/Ext.dataview.component.DataItem\" rel=\"Ext.dataview.component.DataItem\" class=\"docClass\">Ext.dataview.component.DataItem</a>',\n    requires: ['<a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>'],\n    xtype: 'mylistitem',\n\n    config: {\n        nameButton: true,\n\n        dataMap: {\n            getNameButton: {\n                setText: 'name'\n            }\n        }\n    },\n\n    applyNameButton: function(config) {\n        return <a href=\"#!/api/Ext-method-factory\" rel=\"Ext-method-factory\" class=\"docClass\">Ext.factory</a>(config, <a href=\"#!/api/Ext.Button\" rel=\"Ext.Button\" class=\"docClass\">Ext.Button</a>, this.getNameButton());\n    },\n\n    updateNameButton: function(newNameButton, oldNameButton) {\n        if (oldNameButton) {\n            this.remove(oldNameButton);\n        }\n\n        if (newNameButton) {\n            // add an event listeners for the `tap` event onto the new button, and tell it to call the onNameButtonTap method\n            // when it happens\n            newNameButton.on('tap', this.onNameButtonTap, this);\n\n            this.add(newNameButton);\n        }\n    },\n\n    onNameButtonTap: function(button, e) {\n        var record = this.getRecord();\n\n        <a href=\"#!/api/Ext.Msg-method-alert\" rel=\"Ext.Msg-method-alert\" class=\"docClass\">Ext.Msg.alert</a>(\n            record.get('name'), // the title of the alert\n            \"The age of this person is: \" + record.get('age') // the message of the alert\n        );\n    }\n});\n\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.dataview.DataView\" rel=\"Ext.dataview.DataView\" class=\"docClass\">Ext.DataView</a>', {\n    fullscreen: true,\n\n    store: {\n        fields: ['name', 'age'],\n        data: [\n            {name: 'Jamie Avins',  age: 100},\n            {name: 'Rob Dougan',   age: 21},\n            {name: 'Tommy Maintz', age: 24},\n            {name: 'Jacky Nguyen', age: 24},\n            {name: 'Ed Spencer',   age: 26}\n        ]\n    },\n\n    useComponents: true,\n    defaultType: 'mylistitem'\n});\n</code></pre>\n","title":"Using DataView"});