Ext.data.JsonP.native_packaging({"guide":"<h1 id='native_packaging-section-%C2%A0native%C2%A0packaging%C2%A0for%C2%A0mobile-devices'> Native Packaging for Mobile Devices</h1>\n<div class='toc'>\n<p><strong>Contents</strong></p>\n<ol>\n<li><a href='#!/guide/native_packaging-section-native-app-packaging-general-procedures'>Native App Packaging General Procedures</a></li>\n<li><a href='#!/guide/native_packaging-section-required-software'>Required Software</a></li>\n<li><a href='#!/guide/native_packaging-section-step-1%3A-provisioning'>Step 1: Provisioning</a></li>\n<li><a href='#!/guide/native_packaging-section-step-2%3A-create-a-packaging-configuration-file'>Step 2: Create a packaging configuration file</a></li>\n<li><a href='#!/guide/native_packaging-section-step-3%3A-run-the-packager-to-create-the-packaged-application'>Step 3: Run the packager to create the packaged application</a></li>\n<li><a href='#!/guide/native_packaging-section-additional-resources'>Additional Resources</a></li>\n</ol>\n</div>\n\n<p>This guide describes how to package a Sencha Touch app using\n<a href=\"http://www.sencha.com/products/sencha-cmd/download\">Sencha Cmd</a> to run\nnatively on mobile devices using the Sencha Touch Native Packager tool.\nThis tool supports packaging for iOS and Android.</p>\n\n<h2 id='native_packaging-section-native-app-packaging-general-procedures'>Native App Packaging General Procedures</h2>\n\n<p>The app packaging process is similar whether you target iOS or Android devices.\nThe main difference is that each environment requires that you prepare differently\nand create a configuration file with platform-specific parameters.</p>\n\n<p>Basic steps for app packaging:</p>\n\n<ol>\n<li><a href=\"#!/guide/native_packaging-section-provis\">Provisioning</a> - For iOS, complete the iOS provisioning on the\n<a href=\"https://developer.apple.com/ios/manage/overview/index.action\">Apple iOS provisioning portal</a>\n(requires an Apple ID and password) including creating certificates and devices\nset up through the provisioning portal. You also need Xcode and should have\nthe Xcode simulator to test your app before installing on a device.<br>\nFor Android, provisioning requires that you obtain an Android ready\ncertificate (debug or release) to sign your application.</li>\n<li><a href=\"#!/guide/native_packaging-section-cfg\">Create config file</a> - Create a packaging configuration file\nfor use with Sencha Cmd.</li>\n<li><a href=\"#!/guide/native_packaging-section-pkg\">Package your app</a> - Run Sencha Cmd to create a\npackaged <code>\\&lt;application\\&gt;.app</code> file for iOS or an <code>.apk</code> file for Android.</li>\n</ol>\n\n\n<p>This guide lists each step.</p>\n\n<h2 id='native_packaging-section-required-software'>Required Software</h2>\n\n<p>Before you begin, make sure your computer has this software:</p>\n\n<ul>\n<li><strong>JRE</strong> Sencha Cmd is written in Java and requires\n<a href=\"http://www.oracle.com/technetwork/java/javase/downloads/jre7-downloads-1880261.html\">Java Runtime Environment</a>\nversion 1.6 or 1.7 (best)</li>\n<li><a href=\"http://www.sencha.com/products/sencha-cmd/download\">Sencha Cmd</a></li>\n<li><strong>Ruby 1.9.3</strong> (or earlier): Sencha Cmd does not work with Ruby 2.0. Ruby differs by OS:</li>\n<li><strong>Windows</strong>: Download Ruby 1.9.3.n from <a href=\"http://rubyinstaller.org/downloads/\">rubyinstaller.org</a>.\nGet the .exe file version of the software and install it.</li>\n<li><strong>Mac OS</strong>: Ruby is pre-installed. You can test which version you have with the\n<strong>Ruby -v</strong> command. If you have version 2.0, download the <a href=\"https://rvm.io/\">Ruby version manager</a> (rvm).\nUse this command to download and install Ruby: <strong>rvm install 1.9.3 --with-gcc=clang</strong> and set\nyour PATH variable to point to the Ruby 1.9.3 install directory.</li>\n<li><strong>Ubuntu</strong>: Use <strong>sudo apt-get install ruby1.9.3</strong> to download Ruby 1.9.3.</li>\n<li><strong>iOS Packaging</strong>: Apple <a href=\"https://developer.apple.com/xcode/\">Xcode</a></li>\n<li><strong>Android Packaging</strong>: <a href=\"http://developer.android.com/sdk/index.html\">Android SDK Tools</a> and <a href=\"http://www.eclipse.org/\">Eclipse</a> (optional).</li>\n</ul>\n\n\n<p><a name=\"native_packaging-section-provis\"></a></p>\n\n<h2 id='native_packaging-section-step-1%3A-provisioning'>Step 1: Provisioning</h2>\n\n<p>Provisioning differs by platform:</p>\n\n<p><strong>iOS:</strong> Refer to the <a href=\"http://docs.sencha.com/touch/2/#!/guide/native_provisioning\">Native iOS Provisioning Guide</a>\nand use the <a href=\"https://developer.apple.com/ios/manage/overview/index.action\">Apple iOS provisioning portal</a>\n(requires an Apple ID and password) to get a development or distribution certificate and profiles.\nCreate an App ID and provision your application. You need your App ID and App Name to package your app.\nRefer to the How-To section in the\n<a href=\"https://developer.apple.com/ios/manage/overview/index.action\">Apple iOS provisioning portal</a> for help.</p>\n\n<p><strong>Android:</strong> Use the Android SDK Keytool to create a certificate to\nsign your Android application. The following example Keytool command\ngenerates a private key:</p>\n\n<pre>\n$ keytool -genkey -v -keystore my-release-key.keystore -alias alias_name\n    -keyalg RSA -keysize 2048 -validity 10000\n</pre>\n\n\n<p>For more information, see the\nAndroid <a href=\"http://developer.android.com/tools/publishing/app-signing.html\">Signing Your Applications</a>.</p>\n\n<p><a name=\"native_packaging-section-cfg\"></a></p>\n\n<h2 id='native_packaging-section-step-2%3A-create-a-packaging-configuration-file'>Step 2: Create a packaging configuration file</h2>\n\n<p>Create a configuration file template by running the following command in the Terminal:</p>\n\n<pre><code>sencha app package generate &lt;configTemplate.json&gt;\n</code></pre>\n\n<p><code>&lt;configTemplate.json&gt;</code> is the name of the configuration file. The file name cannot contain spaces.</p>\n\n<p>These elements are required to have values--you can use the provided string or change the value:</p>\n\n<ul>\n<li><code>applicationName</code></li>\n<li><code>versionString</code></li>\n<li><code>versionCode</code></li>\n<li><code>inputPath</code></li>\n<li><code>outputPath</code></li>\n<li><code>configuration</code></li>\n<li><code>platform</code></li>\n<li><code>deviceType</code></li>\n<li><code>orientations</code></li>\n</ul>\n\n\n<h3 id='native_packaging-section-applicationname-%28required%29'>applicationName (Required)</h3>\n\n<p>The name of your application, which a device displays to the user after the app is installed.</p>\n\n<p><strong>iOS:</strong> The application name should match the name provided in the\n<a href=\"https://developer.apple.com/ios/manage/overview/index.action\">iOS Provisioning Portal</a>\n(requires an Apple ID and password), in the App IDs section.</p>\n\n<p>This example iOS app ID shows both the name and the ID:</p>\n\n<p><p class='screenshot'><img src='guides/native_packaging/idScreen.png' alt='App ID'><span>App ID</span></p></p>\n\n<p>This example uses:</p>\n\n<ul>\n<li>AppName: Sencha Touch Packaging</li>\n<li>AppID: com.Sencha.TouchPackage</li>\n</ul>\n\n\n<p><strong>Note</strong> The App ID is the same as the one you put in the Identifier field in Xcode.</p>\n\n<p><strong>Android:</strong> The output file has the name \\&lt;AppName>.apk.</p>\n\n<h3 id='native_packaging-section-applicationid-%28optional%29'>applicationId (Optional)</h3>\n\n<p>The ID for your app. Use a name space for your app such as <code>com.sencha.TouchPackage</code>,\nas shown in the previous example. For iOS, the ID can also be found in the provisioning portal.</p>\n\n<h3 id='native_packaging-section-bundleseedid-%28ios-only%29'>bundleSeedId (iOS only)</h3>\n\n<p>The ten-character string in front of the iOS application ID obtained from the\n<a href=\"https://developer.apple.com/ios/manage/overview/index.action\">iOS Provisioning Portal</a>\n(requires an Apple ID and password). In the example shown above under <code>applicationName</code>, it's <code>H8A8ADYR7H</code>.</p>\n\n<h3 id='native_packaging-section-versionstring-%28required%29'>versionString (Required)</h3>\n\n<p>Indicates the version number of your application. This is a string and can have a value such as <code>1.0-beta</code>.</p>\n\n<h3 id='native_packaging-section-versioncode-%28android-only---required-for-android%29'>versionCode (Android only - Required for Android)</h3>\n\n<p>Indicates the build number of an Android app, also called the integer version code.</p>\n\n<h3 id='native_packaging-section-icon-%28optional%29'>icon (Optional)</h3>\n\n<p>Indicates the icon that displays to a user along with your app name on the device's home screen.</p>\n\n<p><strong>iOS:</strong></p>\n\n<ul>\n<li>Specify the icon file to be used for your application.</li>\n<li>Specify a Retina icon with <code>@2x</code> at the end of the icon name.</li>\n<li>A regular icon name looks like <code>icon.png</code>, while a Retina icon looks\nlike <code>(regular) andicon@2x.png</code>. If a Retina icon with the <code>@2x.png</code> exists,\nthe packager includes the Retina icon.</li>\n<li>Refer to the\n<a href=\"https://developer.apple.com/library/ios/#documentation/userexperience/conceptual/mobilehig/IconsImages/IconsImages.html\">Apple documentation about icon sizes</a>.</li>\n<li>iOS uses 57, 72, 114, and 144 pixel icons.</li>\n<li>Specify a target device for your app:</li>\n</ul>\n\n\n<pre>\n\"icon\": {\n    \"57\": \"resources/icons/Icon.png\",\n    \"72\": \"resources/icons/Icon~ipad.png\",\n    \"114\": \"resources/icons/Icon@2x.png\",\n    \"144\": \"resources/icons/Icon~ipad@2x.png\"\n}\n</pre>\n\n\n<p><strong>Android:</strong></p>\n\n<ul>\n<li>Refer to the <a href=\"http://developer.android.com/guide/practices/ui_guidelines/icon_design_launcher.html\">Google Launcher icons guide</a>.</li>\n<li>Android uses 36, 48, 72, and 96 pixel icons.</li>\n<li>If you package for Android, you can omit iOS icons and vice versa.</li>\n<li>Specify a target device for your app, Substitute the correct path\nfor the resources/icon variable in the path. Icons reside in either\nthe res/drawable or res/drawable-hdpi depending on whether the\ndevice is hign density or not.</li>\n</ul>\n\n\n<pre>\n\"icon\": {\n    \"36\":\"resources/icons/Icon_Android36.png\",\n    \"48\":\"resources/icons/Icon_Android48.png\",\n    \"72\":\"resources/icons/Icon_Android72.png\",\n    \"96\":\"resources/icons/Icon_Android96.png\"\n}\n</pre>\n\n\n<p>Refer to the\n<a href=\"https://developer.apple.com/library/ios/#documentation/userexperience/conceptual/mobilehig/IconsImages/IconsImages.html\">Apple documentation</a>\nfor information about icon sizes.</p>\n\n<p><strong>Android:</strong> Specifies the launcher icon file to be used for your application. Refer to the\n<a href=\"http://developer.android.com/guide/practices/ui_guidelines/icon_design_launcher.html\">Android Launcher Icons guide</a>\nfor more information.</p>\n\n<h3 id='native_packaging-section-inputpath-%28required%29'>inputPath (Required)</h3>\n\n<p>Indicates the location of your Sencha Touch application, relative to the configuration file.</p>\n\n<h3 id='native_packaging-section-outputpath-%28required%29'>outputPath (Required)</h3>\n\n<p>Indicates the output location of the packaged application, where the built\napplication file is saved.</p>\n\n<h3 id='native_packaging-section-configuration-%28required%29'>configuration (Required)</h3>\n\n<p>Indicates whether you are building the debug or release configuration of your\napplication. Use <code>Debug</code> unless you are submitting your app to an online store,\nin which case, use <code>Release</code> to submit to an online store.</p>\n\n<h3 id='native_packaging-section-platform-%28required%29'>platform (Required)</h3>\n\n<p>Indicates the platform on which your application runs.</p>\n\n<ul>\n<li><strong>iOS:</strong> Options are <code>iOSSimulator</code> or <code>iOS</code>.</li>\n<li><strong>Android:</strong> Options are <code>Android</code> or <code>AndroidEmulator</code>.</li>\n</ul>\n\n\n<h3 id='native_packaging-section-devicetype-%28ios-only---required-for-ios%29'>deviceType (iOS only - Required for iOS)</h3>\n\n<p>Indicates the iOS device type on which your application runs.</p>\n\n<p>Available options are:</p>\n\n<ul>\n<li>iPhone</li>\n<li>iPad</li>\n<li>Universal</li>\n</ul>\n\n\n<h3 id='native_packaging-section-certificatepath-%28optional%29'>certificatePath (Optional)</h3>\n\n<p>Indicates the location of your certificate, which is required when you are\ndeveloping for Android or Windows.</p>\n\n<h3 id='native_packaging-section-certificatealias-%28optional%29'>certificateAlias (Optional)</h3>\n\n<p>Indicates the name of your certificate. If this is not specified when developing on\nMac OS X, the packaging tool automatically tries to find the certificate using the\napplicationId.</p>\n\n<p>Can be just a simple matcher. For example, if your certificate name is\n\"iPhone Developer: Polly Hedra (ABCDEFGHIJ)\", you can just enter <code>iPhone Developer</code>.</p>\n\n<p>Not required when using a <code>certificatePath</code> on Windows.</p>\n\n<h3 id='native_packaging-section-certificatepassword-%28optional%29'>certificatePassword (Optional)</h3>\n\n<p>Use only if a password was specified when generating certificate for\nrelease build of Android (iOS or Windows), or any iOS build on Windows.\nIndicates that a password is set for the certificate.\nIf a password is not set, leave blank, or delete this parameter.</p>\n\n<h3 id='native_packaging-section-provisionprofile-%28optional%29'>provisionProfile (Optional)</h3>\n\n<p>Indicates a string for the path to the provision profile\n(APP_NAME.mobileprovision), which you can create\nand then download from Apple's provisioning portal.</p>\n\n<h3 id='native_packaging-section-urlscheme-%28optional%29'>URLScheme (Optional)</h3>\n\n<p>Indicates a string for the URL scheme for communication with your application.\nCan be empty if you don't use a custom URL scheme in your project.</p>\n\n<h3 id='native_packaging-section-notificationconfiguration-%28ios-only---optional%29'>notificationConfiguration (iOS only - Optional)</h3>\n\n<p>Optional for apps that use push notifications. Use <code>Debug</code> unless you\nare submitting your app to an online store, in which case use <code>Release</code>.\nIf your app doesn't use push notifications, leave blank or remove this parameter.</p>\n\n<h3 id='native_packaging-section-sdkpath-%28android-only---optional%29'>sdkPath (Android only - Optional)</h3>\n\n<p>Indicates the path to the Android SDK (string).</p>\n\n<h3 id='native_packaging-section-androidapilevel-%28android-only---optional%29'>androidAPILevel (Android only - Optional)</h3>\n\n<p>Indicates the Android API level, which is the version of the Android SDK\nto use. For more information, see\n<a href=\"http://developer.android.com/guide/appendix/api-levels.html\">What is API Level?</a>\nin the Android SDK documentation. Be sure to install the corresponding platform API\nin the Android SDK manager (<em>android_sdk/tools/android</em>).</p>\n\n<p><strong>Note</strong> This parameter is optional, but the default is set to API level 8,\nwhich is Android SDK 2.2 (Froyo). Set to one of the following if you're using a later\nAndroid SDK version:</p>\n\n<ul>\n<li>API level 9 = Android SDK version 2.3 - 2.3.2 - Gingerbread</li>\n<li>API level 10 = Android SDK version 2.3.3 - 2.3.7 - Gingerbread</li>\n<li>API level 11 = Android SDK version 3.0 - Honeycomb</li>\n<li>API level 12 = Android SDK version 3.1 - Honeycomb</li>\n<li>API level 13 = Android SDK version 3.2 - Honeycomb</li>\n<li>API level 14 = Android SDK version 4.0 - 4.0.2 - Ice Cream Sandwich</li>\n<li>API level 15 = Android SDK version 4.0.3 - 4.0.4 - Ice Cream Sandwich</li>\n<li>API level 16 = Android SDK version 4.1.0 - 4.1.2 - Jelly Bean</li>\n<li>API level 17 = Android SDK version 4.2.0 - 4.2.2 - Jelly Bean</li>\n</ul>\n\n\n<h3 id='native_packaging-section-permissions-%28android-only---optional%29'>permissions (Android only - Optional)</h3>\n\n<p>Array of permissions to use with services called from an Android app,\nincluding coarse location, fine location, information about networks,\nthe camera, and so on. See the complete list of permissions in the Android\n<a href=\"http://developer.android.com/reference/android/Manifest.permission.html\">Manifest.permission</a>.</p>\n\n<p>Default values are:</p>\n\n<pre><code>\"INTERNET\",\n\"ACCESS_NETWORK_STATE\",\n\"CAMERA\",\n\"VIBRATE\",\n\"ACCESS_FINE_LOCATION\",\n\"ACCESS_COARSE_LOCATION\",\n\"CALL_PHONE\"\n</code></pre>\n\n<h3 id='native_packaging-section-orientations'>orientations</h3>\n\n<p>Indicates the device orientations in which the application can run.</p>\n\n<p>Options are (all are enabled by default):</p>\n\n<ul>\n<li>portrait</li>\n<li>landscapeLeft</li>\n<li>landscapeRight</li>\n<li>portraitUpsideDown</li>\n</ul>\n\n\n<p><strong>Note</strong> If omitted, the default orientations setting is all four orientations.</p>\n\n<p><a name=\"native_packaging-section-pkg\"></a></p>\n\n<h2 id='native_packaging-section-step-3%3A-run-the-packager-to-create-the-packaged-application'>Step 3: Run the packager to create the packaged application</h2>\n\n<p>After creating the config file, package the app using these procedures\nfor packaging debug and release versions of an app for iOS or Android.</p>\n\n<h3 id='native_packaging-section-ios%3A-package-a-debug-application'>iOS: Package a Debug Application</h3>\n\n<p>The appropriate <code>platform</code> and <code>configuration</code> settings need to be made\nin the config file, for example:</p>\n\n<pre><code>platform: iOSSimulator\nconfiguration: Debug\n</code></pre>\n\n<p>If <code>platform</code> and <code>configuration</code> are not set, the packaged app will\nnot run correctly.</p>\n\n<p>With these configs set properly, issue the following command in Terminal:</p>\n\n<pre><code>sencha app package run &lt;configFile.json&gt;\n</code></pre>\n\n<p>In this example, the iOS Simulator in the <code>platform</code> config parameter\n(in the JSON config file) upon successful completion of the <code>package</code> command,\nlaunches the iOS simulator with the application running natively.\nSee <a href=\"#!/guide/native_packaging-section-cfg\">Step 2</a> for a complete list of variables\nyou can specify in the JSON config file.</p>\n\n<p><strong>Note</strong> Set the <code>deviceType</code> identifier in the JSON config file\nto <code>iPhone</code> or <code>iPad</code> to trigger the appropriate simulator.</p>\n\n<h3 id='native_packaging-section-ios%3A-package-a-release-application'>iOS: Package a Release Application</h3>\n\n<p>To package a signed application to run on the device, issue this\ncommand in the terminal:</p>\n\n<pre><code>sencha app package build &lt;configFile.json&gt;\n</code></pre>\n\n<p><strong>Note</strong> This command creates the <code>&lt;AppName.app&gt;</code> in the directory\nindicated by the outputPath variable in the <em>configFile.json</em>.\nSee <a href=\"#!/guide/native_packaging-section-cfg\">Step 2</a> for a complete list of variables you can specify in\nthe JSON config file. Deploy this application to the iOS device.</p>\n\n<h3 id='native_packaging-section-android%3A-package-a-debug-app-and-run-it-on-the-android-emulator'>Android: Package a Debug App and Run it on the Android Emulator</h3>\n\n<p>The appropriate <code>platform</code> and <code>configuration</code> settings need to be made in the config file, for example:</p>\n\n<pre><code>platform: AndroidEmulator\nconfiguration: Debug\n</code></pre>\n\n<p>If <code>platform</code> and <code>configuration</code> are not set, the packaged app won't run correctly.</p>\n\n<p>With these configs set properly, start the Android Emulator and issue this command:</p>\n\n<pre><code>sencha app package run &lt;configFile.json&gt;\n</code></pre>\n\n<p>In this example, which targets the Android Emulator in the <code>platform</code>\nconfig parameter, successful completion of the <code>package</code> command launches\nthe app in the already running emulator.</p>\n\n<p>If <code>package</code> is successful, an <code>.apk</code> is available in the application\noutputPath location for you to test on an Android Emulator or a device.</p>\n\n<p>More information about the Android Emulator can be found in\n<a href=\"http://developer.android.com/tools/devices/emulator.html\">Android Developer Guide: Using the Android Emulator</a>.</p>\n\n<h3 id='native_packaging-section-android%3A-package-an-application-for-distribution'>Android: Package an application for distribution</h3>\n\n<p>To package a signed application to run on the device, issue the following command:</p>\n\n<pre><code>sencha app package build &lt;configFile.json&gt;\n</code></pre>\n\n<p>This command creates the <code>&lt;AppName.apk&gt;</code> application file that\nyou can use to release for distribution. The APK file is stored in the\ndirectory indicated by the outputPath variable\nin the configFile.json file. See <a href=\"#!/guide/native_packaging-section-cfg\">Step 2</a> for a complete list of variables\nyou can specify in the JSON config file.</p>\n\n<p>You can also use this command to create your APK file:</p>\n\n<pre><code>sencha app build native\n</code></pre>\n\n<h2 id='native_packaging-section-additional-resources'>Additional Resources</h2>\n\n<h3 id='native_packaging-section-ios-resources'>iOS Resources</h3>\n\n<ol>\n<li> <a href=\"http://docs.sencha.com/touch/#!/guide/native_provisioning\">Native iOS Provisioning</a></li>\n<li> <a href=\"https://developer.apple.com/ios/manage/overview/index.action\">Apple iOS provisioning portal</a> (requires an Apple ID and password)</li>\n</ol>\n\n\n<h3 id='native_packaging-section-android-resources'>Android Resources</h3>\n\n<ol>\n<li> <a href=\"http://developer.android.com/tools/publishing/app-signing.html\">Signing Your Applications</a></li>\n<li> <a href=\"http://developer.android.com/tools/sdk/eclipse-adt.html\">Installing the ADT Plugin for Eclipse</a></li>\n<li> <a href=\"http://www.eclipse.org/\">Eclipse</a></li>\n<li> <a href=\"http://developer.android.com/tools/publishing/app-signing.html\">Managing Virtual Devices for Android Emulator</a>, \"Setting up Virtual Devices\".</li>\n</ol>\n\n","title":"Packaging apps for Mobile Devices"});