Ext.data.JsonP.navigation_view({"guide":"<h1 id='navigation_view-section-using-navigation-view-in-sencha-touch'>Using Navigation View in Sencha Touch</h1>\n<div class='toc'>\n<p><strong>Contents</strong></p>\n<ol>\n<li><a href='#!/guide/navigation_view-section-creating-a-simple-navigation-view'>Creating a Simple Navigation View</a></li>\n<li><a href='#!/guide/navigation_view-section-pushing-new-views'>Pushing New Views</a></li>\n<li><a href='#!/guide/navigation_view-section-popping-views'>Popping Views</a></li>\n</ol>\n</div>\n\n<p>Navigation View is a new component in Sencha Touch. At its base, it is a simple container with a card layout and a docked toolbar; however on top of that we built an easy way to push (add) and pop (remove) views in a stack-like manner. When you push a view, it adds that view into the <code>stack</code> and animates the new title into the toolbar. It  also animates a back button into the toolbar, so you can return (or pop) to the previous view.</p>\n\n<p>The following example demonstrates this functionality:</p>\n\n<pre class='inline-example preview'><code>//create the navigation view and add it into the <a href=\"#!/api/Ext.Viewport\" rel=\"Ext.Viewport\" class=\"docClass\">Ext.Viewport</a>\nvar view = <a href=\"#!/api/Ext.Viewport-method-add\" rel=\"Ext.Viewport-method-add\" class=\"docClass\">Ext.Viewport.add</a>({\n    xtype: 'navigationview',\n\n    //we only give it one item by default, which will be the only item in the 'stack' when it loads\n    items: [\n        {\n            //items can have titles\n            title: 'Navigation View',\n            padding: 10,\n\n            //inside this first item we are going to add a button\n            items: [\n                {\n                    xtype: 'button',\n                    text: 'Push another view!',\n                    handler: function() {\n                        //when someone taps this button, it will push another view into stack\n                        view.push({\n                            //this one also has a title\n                            title: 'Second View',\n                            padding: 10,\n\n                            //once again, this view has one button\n                            items: [\n                                {\n                                    xtype: 'button',\n                                    text: 'Pop this view!',\n                                    handler: function() {\n                                        //and when you press this button, it will pop the current view (this) out of the stack\n                                        view.pop();\n                                    }\n                                }\n                            ]\n                        });\n                    }\n                }\n            ]\n        }\n    ]\n});\n</code></pre>\n\n<h2 id='navigation_view-section-creating-a-simple-navigation-view'>Creating a Simple Navigation View</h2>\n\n<p>Creating a Navigation View is similar to creating other containers. You use <a href=\"#!/api/Ext.ClassManager-method-create\" rel=\"Ext.ClassManager-method-create\" class=\"docClass\">Ext.ClassManager.create</a> to create your Navigation View instance, and the only configuration you need to add is <a href=\"#!/api/Ext.navigation.View-cfg-items\" rel=\"Ext.navigation.View-cfg-items\" class=\"docClass\">items</a>.</p>\n\n<pre class='inline-example '><code>var view = <a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.navigation.View\" rel=\"Ext.navigation.View\" class=\"docClass\">Ext.navigation.View</a>', {\n    fullscreen: true,\n    items: [\n        {\n            title: 'Navigation View',\n            html: 'This is the first item in the stack!'\n        }\n    ]\n});\n</code></pre>\n\n<p>In this example, we give the Navigation View the following two configurations:</p>\n\n<ul>\n<li><strong><a href=\"#!/api/Ext.navigation.View-cfg-fullscreen\" rel=\"Ext.navigation.View-cfg-fullscreen\" class=\"docClass\">fullscreen</a></strong>: This ensures that it is automatically inserted into the <a href=\"#!/api/Ext.Viewport\" rel=\"Ext.Viewport\" class=\"docClass\">viewport</a>.</li>\n<li><strong><a href=\"#!/api/Ext.navigation.View-cfg-items\" rel=\"Ext.navigation.View-cfg-items\" class=\"docClass\">items</a></strong>: This represents the items that the navigation view contains. Since we only insert one item here, it the first item in the <code>stack</code> and is therefore active.\n\n<ul>\n<li><strong>title</strong>: This is the title that is displayed in the navigation bar (not required).</li>\n<li><strong><a href=\"#!/api/Ext.Container-cfg-html\" rel=\"Ext.Container-cfg-html\" class=\"docClass\">html</a></strong>: We use the <code>html</code> configuration here for providing some dummy content.</li>\n</ul>\n</li>\n</ul>\n\n\n<h2 id='navigation_view-section-pushing-new-views'>Pushing New Views</h2>\n\n<p>To 'push' means to add a new view to the stack of the navigation view. Pushing will trigger the following three actions:</p>\n\n<ol>\n<li>Animate the navigation view to show the new item (slide).</li>\n<li>Animate the <code>title</code> configuration of the item (if specified) in the navigation bar (slide).</li>\n<li>Animate the back button into the navigation bar (slide).</li>\n</ol>\n\n\n<p>Pushing views is done using the <a href=\"#!/api/Ext.navigation.View-method-push\" rel=\"Ext.navigation.View-method-push\" class=\"docClass\">push</a> method:</p>\n\n<pre><code>view.push({\n    title: 'New views title',\n    html: 'Some content'\n});\n</code></pre>\n\n<p>You can either pass a reference to a component or use a configuration like in the previous example. And of course, the item you push can be any subclass of <a href=\"#!/api/Ext.Component\" rel=\"Ext.Component\" class=\"docClass\">Ext.Component</a>:</p>\n\n<pre><code>var tabPanel = <a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('<a href=\"#!/api/Ext.tab.Panel\" rel=\"Ext.tab.Panel\" class=\"docClass\">Ext.tab.Panel</a>', {\n    items: [\n        {\n            title: 'First',\n            html: 'first'\n        },\n        {\n            title: 'Second',\n            html: 'second'\n        }\n    ]\n});\n\nview.push(tabPanel);\n</code></pre>\n\n<h2 id='navigation_view-section-popping-views'>Popping Views</h2>\n\n<p>To 'pop' means to remove the topmost (the visually active) view from the Navigation View. Of course you need to have more than one item in the stack for this to operation to have have any result. When you pop a view, it perform the following actions:</p>\n\n<ol>\n<li>Animate the navigation view back to the previous item in the stack (reverse slide).</li>\n<li>Animate the current title out of view, and animate the previous stacks title into view (slide).</li>\n<li>Animate the back button out of view, and if there is still more than two items in the stack, animate the back button of the previous view.</li>\n</ol>\n\n\n<p>Popping views is done by calling the <a href=\"#!/api/Ext.navigation.View-method-pop\" rel=\"Ext.navigation.View-method-pop\" class=\"docClass\">pop</a> method:</p>\n\n<pre><code>view.pop();\n</code></pre>\n","title":"Using Navigation View"});